/**
 * Copyright (c) 2013-2016 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see http://www.gnu.org/licenses/
 * for the GNU Lesser General Public License version 2.1.
 */

package org.ow2.petals.registry_overlay.exception;

import java.net.URL;

/**
 * An error occurs reading the local cluster member configuration resources
 * 
 * @author Christophe DENEUX - Linagora
 * 
 */
public class ClusterMemberCfgReadErrorException extends PetalsRegistryOverlayException {

    private static final long serialVersionUID = -1763302304596836987L;

    /**
     * The URL of the local cluster member configuration resource for which a reading error
     * occurs.
     */
    private final URL clusterMemberCfgUrl;

    public ClusterMemberCfgReadErrorException(final URL clusterMemberCfgUrl, final Throwable throwable) {
        super("An error occurs reading the local cluster member configuration resource  ["
                + clusterMemberCfgUrl.toString() + "] !!", throwable);
        this.clusterMemberCfgUrl = clusterMemberCfgUrl;
    }

    /**
     * @return The URL of the local cluster member configuration resource for which a reading
     *         error occurs.
     */
    public URL getClusterMemberCfgUrl() {
        return this.clusterMemberCfgUrl;
    }

}
